# Visualization


## flyvis.analysis.visualization.figsize_utils


### Functions

::: flyvis.analysis.visualization.figsize_utils.figsize_from_n_items
    options:
      heading_level: 4

::: flyvis.analysis.visualization.figsize_utils.figure_size_cm
    options:
      heading_level: 4

::: flyvis.analysis.visualization.figsize_utils.fit_panel_size
    options:
      heading_level: 4

::: flyvis.analysis.visualization.figsize_utils.cm_to_inch
    options:
      heading_level: 4

### Classes

::: flyvis.analysis.visualization.figsize_utils.FigsizeCM
    options:
      heading_level: 4

## flyvis.analysis.visualization.network_fig


### Classes

::: flyvis.analysis.visualization.network_fig.WholeNetworkFigure
    options:
      heading_level: 4

### Functions

::: flyvis.analysis.visualization.network_fig.network_layout_axes
    options:
      heading_level: 4

::: flyvis.analysis.visualization.network_fig._network_graph_node_pos
    options:
      heading_level: 4

## flyvis.analysis.visualization.plots



### Functions

::: flyvis.analysis.visualization.plots.heatmap
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.hex_scatter
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.kernel
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.hex_cs
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.quick_hex_scatter
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.hex_flow
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.quick_hex_flow
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.flow_to_rgba
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.plot_flow
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.traces
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.grouped_traces
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.get_violin_x_locations
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.violin_groups
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.plot_complex
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.plot_complex_vector
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.polar
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.multi_polar
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.loss_curves
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.histogram
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.violins
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plots.plot_strf
    options:
      heading_level: 4

### Classes

::: flyvis.analysis.visualization.plots.ViolinData
    options:
      heading_level: 4

## flyvis.analysis.visualization.plt_utils


### Functions

::: flyvis.analysis.visualization.plt_utils.check_markers
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.get_marker
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.init_plot
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.truncate_colormap
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.rm_spines
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.get_ax_positions
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.is_hex
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.is_integer_rgb
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.get_alpha_colormap
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.polar_to_cmap
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.add_colorwheel_2d
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.add_cluster_marker
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.derive_position_for_supplementary_ax
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.derive_position_for_supplementary_ax_hex
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.add_colorbar_to_fig
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.get_norm
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.get_scalarmapper
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.get_lims
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.avg_pool
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.width_n_height
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.get_axis_grid
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.figure
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.subplot
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.divide_axis_to_grid
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.divide_figure_to_grid
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.scale
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.ax_scatter
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.color_labels
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.color_label
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.boldify_labels
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.scatter_on_violins_or_bars
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.set_spine_tick_params
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.scatter_on_violins_with_best
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.trim_axis
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.display_significance_value
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.display_pvalues
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.closest_divisors
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.standalone_legend
    options:
      heading_level: 4

::: flyvis.analysis.visualization.plt_utils.extend_arg
    options:
      heading_level: 4
